================
Blazar dashboard
================

Horizon plugin for the Blazar Reservation Service for OpenStack

* Free software: Apache license
* Source: https://git.openstack.org/cgit/openstack/blazar-dashboard
* Bugs: https://bugs.launchpad.net/blazar

Features
--------

The following features are currently supported:

* Leases panel in the Reservations group of the Project dashboard

   * Show a list of leases
   * Show details of a lease
   * Create a lease
   * Update a lease
   * Delete lease(s)

* Hosts panel in the Reservation group of the Admin dashboard

   * Show a list of hosts
   * Show details of a host
   * Create host(s)
   * Update a host
   * Delete host(s)

Using Blazar dashboard
----------------------

.. toctree::
   :maxdepth: 1

   install

Source Code Reference
---------------------

.. toctree::
   :glob:
   :maxdepth: 1

   sourcecode/autoindex
